<?php
/*
* $Id: cm_header_shop_by_price.php
* $Loc: /includes/modules/content/header/
*
* Name: ShopByPrice
* Version: 5.3.3
* Release Date: 2024-07-30
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class cm_header_shop_by_price extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_CONTENT_HEADER_SHOP_BY_PRICE_';

    function __construct() {
      parent::__construct(__FILE__);

      $this->description .= '<p>by @raiwa <u><a target="_blank" href="http://www.oscaddons.com">www.oscaddons.com</a></u></p>';

    }

    function execute() {
      global $current_category_id, $Linker;

      $price_ranges = [];

      $price_ranges_array = explode(',', constant('MODULE_CONTENT_HEADER_SHOP_BY_PRICE_PRICE_RANGE_' . $_SESSION['currency']));
      $price_ranges[0] =  MODULE_CONTENT_HEADER_SHOP_BY_PRICE_LESS_THAN .  $this->format0($price_ranges_array[0], false);
      for ($price_range=1; $price_range<sizeof($price_ranges_array); $price_range++) {
        $price_ranges[$price_range] = $this->format0($price_ranges_array[$price_range-1]). " &minus; " . $this->format0($price_ranges_array[$price_range]);
      }
      $price_ranges[sizeof($price_ranges_array)] =  MODULE_CONTENT_HEADER_SHOP_BY_PRICE_MORE_THAN .  $this->format0($price_ranges_array[sizeof($price_ranges_array)-1]);
      $price_ranges[sizeof($price_ranges_array)+1] =  MODULE_CONTENT_HEADER_SHOP_BY_PRICE_ALL;

      $price_range_list = [];
      $price_range_list[] = ['id' => '0', 'text' => PULL_DOWN_DEFAULT];

      for ($range=1; $range<sizeof($price_ranges)+1; $range++) {
        $price_range_list[] = ['id' => $range, 'text' => $price_ranges[$range-1]];
      }

      $range = (isset($_GET['lrange'])? $_GET['lrange']+1 : $_GET['range'] ?? null);

      $link = $Linker->build('shop_by_price.php');
      $form = new Form('shop_price', $link, 'get', ['role' => 'form']);
      foreach ((clone $link)->retain_query_except(['range', 'lrange', 'action'])->get_parameters() as $key => $value) {
        $form->hide($key, $value);
      }

      $tpl_data = [ 'group' => $this->group, 'file' => __FILE__ ];
      include 'includes/modules/content/cm_template.php';
    }

    protected function get_parameters() {
      $config_parameters = [
        $this->config_key_base . 'STATUS' => [
          'title' => 'Enable Shop by Price Module',
          'value' => 'True',
          'desc' => 'Do you want to add the module to your shop?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'CONTENT_WIDTH' => [
          'title' => 'Content Container',
          'value' => 'col-sm-4 align-self-center',
          'desc' => 'What container should the content be shown in? (col-*-12 = full width, col-*-6 = half width).',
        ],
        $this->config_key_base . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '25',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
        $this->config_key_base . 'USE_FAST_TAX_QUERY' => [
          'title' => 'Use fast Tax Query',
          'value' => 'True',
          'desc' => 'Should work for most shops with standard tax settings.<br>Set to false if you have very complicate tax sttings with several Tax zones/types and get missing products in range results.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'USE_DECIMAL' => [
          'title' => 'Use decimal places',
          'value' => 'False',
          'desc' => 'Do you want to use decimal places for the price ranges?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
      ];
      
      $currencies = new currencies();
      foreach($currencies->currencies as $key => $value) {
        $config_parameters['MODULE_CONTENT_HEADER_SHOP_BY_PRICE_PRICE_RANGE_' . $key] = [
            'title' => 'Price Range  ' . $key,
            'value' => '10,20,30,50,100',
            'desc' => 'Price Range Steps separated by comma for ' . $key . ' currency.<br>Default:"10,20,30,50,100"<br>If decimals, use point for decimal separator. Example: 2.50',
        ];
      }
      
      return $config_parameters;
      
    }

    function format0($number, $currency_type = '', $currency_value = '') {
      global $calculate_currency_value;

      if (empty($currency_type)) $currency_type = $_SESSION['currency'];

      if ( defined('MODULE_CONTENT_HEADER_SHOP_BY_PRICE_USE_DECIMAL') && MODULE_CONTENT_HEADER_SHOP_BY_PRICE_USE_DECIMAL == 'True') {
        if ($calculate_currency_value == true) {
          $rate = (!Text::is_empty($currency_value)) ? $currency_value : $GLOBALS['currencies']->currencies[$currency_type]['value'];
          $format_string = $GLOBALS['currencies']->currencies[$currency_type]['symbol_left'] . number_format(currencies::round($number * $rate, $GLOBALS['currencies']->currencies[$currency_type]['decimal_places']), $GLOBALS['currencies']->currencies[$currency_type]['decimal_places'], $GLOBALS['currencies']->currencies[$currency_type]['decimal_point'], $GLOBALS['currencies']->currencies[$currency_type]['thousands_point']) . $GLOBALS['currencies']->currencies[$currency_type]['symbol_right'];
        } else {
          $format_string = $GLOBALS['currencies']->currencies[$currency_type]['symbol_left'] . number_format(currencies::round($number, $GLOBALS['currencies']->currencies[$currency_type]['decimal_places']), $GLOBALS['currencies']->currencies[$currency_type]['decimal_places'], $GLOBALS['currencies']->currencies[$currency_type]['decimal_point'], $GLOBALS['currencies']->currencies[$currency_type]['thousands_point']) . $GLOBALS['currencies']->currencies[$currency_type]['symbol_right'];
        }
      } else {
        if ($calculate_currency_value == true) {
          $rate = (!Text::is_empty($currency_value)) ? $currency_value : $GLOBALS['currencies']->currencies[$currency_type]['value'];
          $format_string = $GLOBALS['currencies']->currencies[$currency_type]['symbol_left'] . number_format(currencies::round(round($number * $rate, $round_places), $GLOBALS['currencies']->currencies[$currency_type]['decimal_places']), 0, $GLOBALS['currencies']->currencies[$currency_type]['decimal_point'], $GLOBALS['currencies']->currencies[$currency_type]['thousands_point']) . $GLOBALS['currencies']->currencies[$currency_type]['symbol_right'];
        } else {
          $format_string = $GLOBALS['currencies']->currencies[$currency_type]['symbol_left'] . number_format(currencies::round($number, $GLOBALS['currencies']->currencies[$currency_type]['decimal_places']), 0, $GLOBALS['currencies']->currencies[$currency_type]['decimal_point'], $GLOBALS['currencies']->currencies[$currency_type]['thousands_point']) . $GLOBALS['currencies']->currencies[$currency_type]['symbol_right'];
        }
      }

      return $format_string;
    }
  }
